SystemOrganization addCategory: #'RFBExtensions-Tests'!

TestCase subclass: #SSHTunnelTest
	instanceVariableNames: 'sut sut2 echoProcess'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RFBExtensions-Tests'!

!SSHTunnelTest methodsFor: 'helping' stamp: 'SR 4/28/2009 10:00'!
echoServer

   | server socketStream socket data |
   Socket initializeNetwork.
   [server := Socket newTCP.
   server listenOn: 7000 backlogSize: 4.
   2 timesRepeat: 
      [ 
      socket := server waitForAcceptFor: 60.
      socketStream := SocketStream on: socket.
      [socket notNil and: [socketStream isConnected]] whileTrue: 
         [data := socketStream upToAll: String crlf.
         socketStream
            nextPutAll: data;
            crlf;
            flush].
      socket notNil
         ifTrue:[socket closeAndDestroy]]]
   ensure:
      [server closeAndDestroy].! !

!SSHTunnelTest methodsFor: 'helping' stamp: 'mig 4/28/2009 14:59'!
sendAndWaitReply
	
	^ Socket
		pingPorts: #(7001)
		on: '127.0.0.1'
		timeOutSecs: 20.
! !

!SSHTunnelTest methodsFor: 'running' stamp: 'mig 4/28/2009 14:58'!
setUp
	
	super setUp.
	sut := SSHTunnel new.
	sut2 := SSHTunnel new.
	echoProcess := [self echoServer] fork.! !

!SSHTunnelTest methodsFor: 'running' stamp: 'mig 4/28/2009 14:59'!
tearDown
	
	echoProcess terminate.
	super tearDown.! !

!SSHTunnelTest methodsFor: 'tests' stamp: 'mig 4/28/2009 14:59'!
testSSHTunnelWithDefaultServer

	sut localPort: 7000.
	sut remotePort: 7002.
	
	sut2 isLocalTunnel: true.
	sut2 remotePort: 7002.
	sut2 localPort: 7001.
	
	sut execute.
	sut2 execute.

	(0 to: 10) 
		do: [:ignore | (Delay forMilliseconds: 600) wait]
		displayingProgress: 'Giving SSH connection some time...'. 
	
	self sendAndWaitReply.
	
	sut2 terminate.
	sut terminate.! !

XpfRestTest subclass: #XpfRfbTunnelHttpHandlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'RFBExtensions-Tests'!

!XpfRfbTunnelHttpHandlerTest methodsFor: 'running' stamp: 'cs 6/2/2009 19:22'!
setUp

	super setUp.
	RestHttpService resource installHandler:
		XpfRfbTunnelHttpHandler initialize new.! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'running' stamp: 'bs 4/17/2009 15:20'!
tearDown
	super tearDown.
	XpfRfbTunnelHttpHandler initialize.! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'tests' stamp: 'bs 4/27/2009 13:03'!
testAssigningAndFreeingPorts
	| firstPort portA portB testDuration freePort openedServices serviceA serviceB |
	openedServices := OrderedCollection new.
	[
	testDuration := Duration milliSeconds: 10. 
	XpfRfbTunnelHttpHandler pendingTime: testDuration.
	
	firstPort := XpfRfbTunnelHttpHandler firstPort.
	portA := XpfRfbTunnelHttpHandler assignAvailablePortTo: 'a'.
	self assert: [firstPort == portA]. 
	serviceA := HttpService startOn: portA.
	openedServices add: serviceA.
	
	(Delay forDuration: (testDuration * 2)) wait.
	
	portB := XpfRfbTunnelHttpHandler assignAvailablePortTo: 'b'.
	self assert: [(firstPort + 1) == portB].
	serviceB := HttpService startOn: portB.
	openedServices add: serviceB.
	
	(Delay forDuration: (testDuration * 2)) wait.
	
	serviceA unregister.
	self assert: [(firstPort) == (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'a')].
	
	freePort := XpfRfbTunnelHttpHandler assignAvailablePortTo: 'c'.
	self assert: [(firstPort + 2) == freePort] description: ('should: {1}; was: {2}' format: {firstPort + 2. freePort}).
	
	serviceB unregister.
	self assert: [(firstPort + 1) == (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'b')].
	
	] ensure: [ 
		openedServices do: [:aService | aService isRunning ifTrue: [aService unregister]]
	].
	! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'tests' stamp: 'bs 5/5/2009 16:47'!
testDifferentUserDifferentPort
	| firstPort testDuration |
	
	testDuration := Duration milliSeconds: 10. 
	XpfRfbTunnelHttpHandler pendingTime: testDuration.
	
	firstPort := XpfRfbTunnelHttpHandler firstPort.
	
	self should: [firstPort == (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'a')].
	self shouldnt: [(firstPort == (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'b'))].! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'tests' stamp: 'bs 4/27/2009 13:03'!
testFreeingAfterPendingTime
	| firstPort freePort testDuration |
	
	testDuration := Duration milliSeconds: 10. 
	XpfRfbTunnelHttpHandler pendingTime: testDuration.
	
	firstPort := XpfRfbTunnelHttpHandler firstPort.
	
	freePort := (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'c').
	self assert: [firstPort == freePort] description: ('should: {1}; was: {2}' format: {firstPort. freePort}).
	(Delay forDuration: (testDuration * 2)) wait.
	
	freePort := (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'c').
	self assert: [firstPort == freePort] description: ('should: {1}; was: {2}' format: {firstPort. freePort}).
	
	! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'tests' stamp: 'bs 7/1/2009 12:03'!
testGetRequest
	| response |
	response := self get: 'rfb'.
	self should: response responseCode = 200.
	self should: response content asInteger = XpfRfbTunnelHttpHandler firstPort.! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'tests' stamp: 'bs 7/1/2009 12:05'!
testGetRequestForDifferentUser
	| response response2 testDuration |
	testDuration := Duration milliSeconds: 5000. 
	XpfRfbTunnelHttpHandler pendingTime: testDuration.
	
	response := self get: 'rfb'.
	self should: response responseCode = 200.
	self should: response content asInteger = XpfRfbTunnelHttpHandler firstPort.
	
	ActiveHand login: (self class login2) password: (self class password).
	response2 := self get: 'rfb'.
	self should: response2 responseCode = 200.
	self shouldnt: response2 content asInteger = XpfRfbTunnelHttpHandler firstPort.! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'tests' stamp: 'bs 4/27/2009 13:04'!
testSameUserSamePort
	| firstPort testDuration |
	
	testDuration := Duration milliSeconds: 1. 
	XpfRfbTunnelHttpHandler pendingTime: testDuration.
	
	firstPort := XpfRfbTunnelHttpHandler firstPort.
	
	self assert: [firstPort == (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'a')].
	self assert: [firstPort == (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'a')].! !
